@@ -268,9 +268,7 @@ class ApiGatewayAdditionalRoute(models.Model):
         # constraints = [
         #     models.UniqueConstraint("api_gateway", 'name', name='unique_name_per_gateway')
         # ]
-        unique_together = [
-            ["api_gateway", 'route_key']
-        ]
+        unique_together = [["api_gateway", "route_key"]]
 
     def __str__(self) -> str:
         return self.name
